@@ -41,6 +41,9 @@
 #' number of iterations } \item{w }{Amount of imputed values} \item{wind
 #' }{Index of the missing values in the data}
 #' @author Matthias Templ, Karel Hron
+#' @export
+#' @importFrom VIM kNN
+#' @importFrom robustbase ltsReg
 #' @seealso \code{\link{impKNNa}}, \code{\link{isomLR}}
 #' @references Hron, K. and Templ, M. and Filzmoser, P. (2010) Imputation of
 #' missing values for compositional data using classical and robust methods
@@ -224,7 +227,7 @@ function(x, maxit=10, eps=0.5, method="ltsReg", closed=FALSE,
 			    x[,1]=xNA
 			    x[,indM[i]]=x1
 			
-			    if( closed == FALSE ) xilr=isomLR(x) else xilr=x
+			    if( closed == FALSE ) xilr <- isomLR(x) else xilr=x
 			
 			    #apply the PCA algorithm -> ximp
 			    ind <- cbind(w[, indM[i]], rep(FALSE, dim(w)[1]))
@@ -257,7 +260,7 @@ function(x, maxit=10, eps=0.5, method="ltsReg", closed=FALSE,
 				  xilr <- data.frame(xilr)
 				  c1 <- colnames(xilr)[1]
 				  colnames(xilr)[1] <- "V1"
-				  reg1 = ltsReg(V1 ~ ., data=xilr)
+				  reg1 = robustbase::ltsReg(V1 ~ ., data=xilr)
 				  imp= as.matrix(cbind(rep(1, nrow(xilr)), xilr[,-1])) %*% reg1$coef 
 				  colnames(xilr)[1] <- c1
 			      ##imp= cbind(rep(1, nrow(xilr)), xilr[,-1]) %*% reg1$coef  
@@ -317,7 +320,7 @@ function(x, maxit=10, eps=0.5, method="ltsReg", closed=FALSE,
 				#  xilr[w[, indM[i]], 1] <- reg1[w[, indM[i]]] 
 				#}
 			
-				if( closed == FALSE ) x=isomLRinv(xilr) else x=xilr
+				if( closed == FALSE ) x <- isomLRinv(xilr) else x=xilr
 #				if( closed == FALSE && method %in% c("roundedZero","roundedZeroRobust")) x=invilrM(xilr) else x=xilr			
 				#return the order of columns
 			
@@ -343,7 +346,7 @@ function(x, maxit=10, eps=0.5, method="ltsReg", closed=FALSE,
 				x1=x[,1]
 				x[,1]=xNA
 				x[,indM[i]]=x1
-				if( closed == FALSE ) xilr=isomLR(x) else xilr=x
+				if( closed == FALSE ) xilr <- -isomLR(x) else xilr=x
 				  ind <- cbind(w[, indM[i]], rep(FALSE, dim(w)[1]))	
 				  xilr <- data.frame(xilr)
 				  #c1 <- colnames(xilr)[1]
@@ -354,7 +357,7 @@ function(x, maxit=10, eps=0.5, method="ltsReg", closed=FALSE,
 				  xilr[w[, indM[i]], 1] <- xilr[w[, indM[i]], 1] +  
 				    rnorm(length(which(w[, indM[i]])), 0, sd=error[indM[i]]) 
 				  xilr <- data.frame(xilr)
-				  if( closed == FALSE ) x=isomLRinv(xilr) else x=xilr
+				  if( closed == FALSE ) x <- isomLRinv(-xilr) else x=xilr
 				  xNA=x[,1]
 				  x1=x[,indM[i]]
 				  x[,1]=x1
