@@ -35,6 +35,7 @@
 #' components. Only important for method \dQuote{pls}.
 #' @param correction normal or density
 #' @param verbose additional print output during calculations.
+#' @param test an internal test situation (this parameter will be deleted soon)
 #' @importFrom cvTools cvFit
 #' @import pls
 #' @return \item{x }{imputed data} \item{criteria }{change between last and
@@ -50,19 +51,31 @@
 #' @importFrom MASS rlm
 #' @examples
 #' 
-#' data(arcticLake)
-#' x <- arcticLake
+#' data(mcad)
+#' \dontrun{
 #' ## generate rounded zeros artificially:
-#' #x[x[,1] < 5, 1] <- 0
-#' x[x[,2] < 44, 2] <- 0
-#' xia <- impRZilr(x, dl=c(5,44,0), eps=0.01, method="lm")
-#' xia$x
+#' x <- x[1:25, 2:ncol(x)]
+#' dl <- apply(x, 2, quantile, 0.1)
+#' for(i in seq(1, ncol(x), 2)){
+#'   x[x[,i] < dl[i], i] <- 0
+#' } 
+#' ni <- sum(x==0, na.rm=TRUE) 
+#' ni/(ncol(x)*nrow(x)) * 100
+#' dl[seq(2, ncol(x), 2)] <- 0
+#' replaced_lm <- imputeBDLs(x, dl=dl, eps=1, method="lm",  
+#'   verbose=FALSE, R=50, variation=TRUE)$x
+#' replaced_lmrob <- imputeBDLs(x, dl=dl, eps=1, method="lmrob",  
+#'   verbose=FALSE, R=50, variation=TRUE)$x
+#' replaced_plsfull <- imputeBDLs(x, dl=dl, eps=1, 
+#'   method="pls", verbose=FALSE, R=50, 
+#'   variation=FALSE)$x 
+#' }
 `imputeBDLs` <-
   function(x, maxit=10, eps=0.1, method="pls", 
            dl=rep(0.05, ncol(x)), variation=TRUE,	nPred=NULL, 
            nComp = "boot", bruteforce=FALSE,  
            noisemethod="residuals", noise=FALSE, R=10, 
-           correction="normal", verbose=FALSE){
+           correction="normal", verbose=FALSE, test = FALSE){
       
     ## check if data are fine
     checkData(x, dl)
@@ -153,11 +166,11 @@
           s <- sort(rv)[np]
           cols <- which(rv <= s)[1:np]
           xn <- xneworder[, cols]
-          xilr <- data.frame(isomLR(xn))
+          if(test) xilr <- data.frame(isomLRp(xn)) else xilr <- data.frame(isomLR(xn))
           colnames(xilr)[1] <- "Y"
           call <- call(method, formula = Y ~ .)
           # perform cross-validation
-          cve[np] <- suppressWarnings(cvFit(call, data = xilr, y = xilr$Y, cost = rtmspe,
+          cve[np] <- suppressWarnings(cvFit(call, data = xilr, y = xilr$Y, cost = cvTools::rtmspe,
                     K = 5, R = 1, costArgs = list(trim = 0.1), seed = 1234)$cv)
         }
         nPred[i] <- which.min(cve)
@@ -195,10 +208,10 @@
         ## detection limit in ilr-space
         forphi <- cbind(rep(dlordered[i], n), xneworder[,-1,drop=FALSE])
         if(any(is.na(forphi))) break()
-        phi <- isomLR(forphi)[,1] 
+        if(test) phi <- isomLRp(forphi)[,1] else phi <- isomLR(forphi)[,1] 
         #		part <- cbind(x[,i,drop=FALSE], x[,-i,drop=FALSE])
         xneworder[xneworder < 2*.Machine$double.eps] <- 2*.Machine$double.eps
-        xilr <- data.frame(isomLR(xneworder))
+        if(test) xilr <- data.frame(isomLRp(xneworder)) else xilr <- data.frame(isomLR(xneworder))
 #        c1 <- colnames(xilr)[1]					
 #        colnames(xilr)[1] <- "V1"	
         response <- as.matrix(xilr[, 1, drop=FALSE])
@@ -221,6 +234,7 @@
         
         #		s <- sqrt(sum(reg1$res^2)/abs(nrow(xilr)-ncol(xilr))) ## quick and dirty: abs()
         s <- sqrt(sum(reg1$res^2)/nrow(xilr)) 
+        yhat <- as.numeric(yhat)
         ex <- (phi - yhat)/s 
         if(correction=="normal"){
           yhat2sel <- ifelse(dnorm(ex[w[, i]]) > .Machine$double.eps,
@@ -236,7 +250,7 @@
           yhat2sel <- ifelse(yhat2sel > phi[w[, i]], phi[w[, i]], yhat2sel)
         }
         xilr[w[, i], 1] <- yhat2sel
-        xinv <- isomLRinv(xilr)
+        if(test) xinv <- isomLRinvp(xilr) else xinv <- isomLRinv(xilr)
         ## if variation:
         if(variation == TRUE){
           xneworder <- adjustImputed(xinv, xneworder, w2[, cols])
@@ -298,7 +312,7 @@
           yhat2sel <- ifelse(yhat2sel > phi[w[, i]], phi[w[, i]], yhat2sel)
         }
         xilr[w[, i], 1] <- yhat2sel
-        xinv <- isomLRinv(xilr)
+        if(test) xinv <- isomLRinvp(xilr) else xinv <- isomLRinv(xilr) 
         ## reordering of xOrig
         if(i %in% 2:(d-1)){
           xinv <- cbind(xinv[,2:i], xinv[,c(1,(i+1):d)])
