@@ -4,15 +4,15 @@ robilrregression <- function(X,y){
 #
 # classical regression
 d <- data.frame(y=y,X=X)
-lmcla <- ltsReg(y~.,data=d)
+lmcla <- robustbase::ltsReg(y~.,data=d)
 lmcla.sum <- summary(lmcla)
 # ilr regressions:
 require(robCompositions)
 ilr.sum <- lmcla.sum
 for (j in 1:ncol(X)){
-  Zj <- -robCompositions::isomLR(cbind(X[,j],X[,-j]))
+  Zj <- isomLR(cbind(X[,j],X[,-j]))
   dj <- data.frame(y=y,Z=Zj)
-  res <- ltsReg(y~.,data=dj)
+  res <- robustbase::ltsReg(y~.,data=dj)
   res.sum <- summary(res)
   if (j==1){
     ilr.sum$coefficients[1:2,] <- res.sum$coefficients[1:2,]
